dot2tex - A Graphviz to LaTeX converter
=======================================

:Author: Kjell Magne Fauske
:Version: 2.11.2
:Licence: MIT_


The purpose of dot2tex is to give graphs generated by Graphviz_ a more LaTeX
friendly look and feel. This is accomplished by converting xdot output from
Graphviz_ to a series of PSTricks_ or `PGF/TikZ`_ commands. This approach allows:

    * Typesetting labels with LaTeX, allowing mathematical notation
    * Using native PSTricks and PGF/TikZ commands for drawing arrows
    * Using backend specific styles to customize the output


User's guide
============

.. toctree::
   :maxdepth: 2
   :numbered:

   installation_guide
   usage_guide
   customization_guide
   tipsandtricks
   module_guide


Additional notes
================

.. toctree::
   :maxdepth: 2

   Change log <changelog>
   license


Acknowledgements
================

The dot parser used by dot2tex is based on code from the pydot_ project.


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. include:: common.inc